@@ -1,10 +1,12 @@
 from argostranslate.translate import ITranslation
 
+from argostranslatefiles.formats.html import Html
 from argostranslatefiles.formats.opendocument.odp import Odp
 from argostranslatefiles.formats.opendocument.odt import Odt
 from argostranslatefiles.formats.openxml.docx import Docx
 from argostranslatefiles.formats.openxml.pptx import Pptx
 from argostranslatefiles.formats.txt import Txt
+from argostranslatefiles.formats.epub import Epub
 
 
 def get_supported_formats():
@@ -13,7 +15,9 @@ def get_supported_formats():
         Odt(),
         Odp(),
         Docx(),
-        Pptx()
+        Pptx(),
+        Epub(),
+        Html()
     ]
 
 
